@@ -2,6 +2,8 @@ import re
 import string
 from json import load
 from os import getcwd
+from . import slang_list
+
 def remove_punctuation(text):
     return text.translate(str.maketrans('', '', string.punctuation))
 
@@ -41,6 +43,5 @@ def remove_url(text):
     return re.sub(r'http\S+', '', text)
 
 def remove_slang(text):
-    with open(getcwd() + '\\src\\cleaner_id\\slang.json') as f:
-        slang_words = load(f)
+    slang_words = slang_list.slang_words
     return ' '.join([(slang_words[t] if t in slang_words.keys() else t) for t in text.split()])
